@@ -1,28 +1,28 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2009-2010 by Michel Ludwig <michel.ludwig@kdemail.net>
- *  Copyright (C) 2008 Mirko Stocker <me@misto.ch>
- *  Copyright (C) 2004-2005 Anders Lund <anders@alweb.dk>
- *  Copyright (C) 2002 John Firebaugh <jfirebaugh@kde.org>
- *  Copyright (C) 2001-2004 Christoph Cullmann <cullmann@kde.org>
- *  Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
- *  Copyright (C) 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
+
+    Copyright (C) 2009-2010 by Michel Ludwig <michel.ludwig@kdemail.net>
+    Copyright (C) 2008 Mirko Stocker <me@misto.ch>
+    Copyright (C) 2004-2005 Anders Lund <anders@alweb.dk>
+    Copyright (C) 2002 John Firebaugh <jfirebaugh@kde.org>
+    Copyright (C) 2001-2004 Christoph Cullmann <cullmann@kde.org>
+    Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
+    Copyright (C) 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 #include "spellcheckdialog.h"
 
@@ -42,11 +42,10 @@
 KateSpellCheckDialog::KateSpellCheckDialog(KTextEditor::ViewPrivate *view)
     : QObject(view)
     , m_view(view)
-    , m_spellcheckSelection(NULL)
-    , m_speller(NULL)
-    , m_backgroundChecker(NULL)
-    , m_sonnetDialog(NULL)
-    , m_globalSpellCheckRange(NULL)
+    , m_speller(nullptr)
+    , m_backgroundChecker(nullptr)
+    , m_sonnetDialog(nullptr)
+    , m_globalSpellCheckRange(nullptr)
     , m_spellCheckCancelledByUser(false)
 {
 }
@@ -68,22 +67,15 @@ void KateSpellCheckDialog::createActions(KActionCollection *ac)
     a->setIcon(QIcon::fromTheme(QStringLiteral("tools-check-spelling")));
     a->setWhatsThis(i18n("Check the document's spelling from the cursor and forward"));
     connect(a, SIGNAL(triggered()), this, SLOT(spellcheckFromCursor()));
-
-    m_spellcheckSelection = new QAction(i18n("Spellcheck Selection..."), this);
-    ac->addAction(QStringLiteral("tools_spelling_selection"), m_spellcheckSelection);
-    m_spellcheckSelection->setIcon(QIcon::fromTheme(QStringLiteral("tools-check-spelling")));
-    m_spellcheckSelection->setWhatsThis(i18n("Check spelling of the selected text"));
-    connect(m_spellcheckSelection, SIGNAL(triggered()), this, SLOT(spellcheckSelection()));
-}
-
-void KateSpellCheckDialog::updateActions()
-{
-    m_spellcheckSelection->setEnabled(m_view->selection());
 }
 
 void KateSpellCheckDialog::spellcheckFromCursor()
 {
-    spellcheck(m_view->cursorPosition());
+    if (m_view->selection()) {
+        spellcheckSelection();
+    } else {
+        spellcheck(m_view->cursorPosition());
+    }
 }
 
 void KateSpellCheckDialog::spellcheckSelection()
@@ -93,7 +85,11 @@ void KateSpellCheckDialog::spellcheckSelection()
 
 void KateSpellCheckDialog::spellcheck()
 {
-    spellcheck(KTextEditor::Cursor(0, 0));
+    if (m_view->selection()) {
+        spellcheckSelection();
+    } else {
+        spellcheck(KTextEditor::Cursor(0, 0));
+    }
 }
 
 void KateSpellCheckDialog::spellcheck(const KTextEditor::Cursor &from, const KTextEditor::Cursor &to)
@@ -120,32 +116,26 @@ void KateSpellCheckDialog::spellcheck(const KTextEditor::Cursor &from, const KTe
         m_sonnetDialog->showSpellCheckCompletionMessage();
         m_sonnetDialog->setSpellCheckContinuedAfterReplacement(false);
 
-        m_view->bottomViewBar()->addBarWidget(m_sonnetDialog);
-
         connect(m_sonnetDialog, SIGNAL(done(QString)), this, SLOT(installNextSpellCheckRange()));
 
-        connect(m_sonnetDialog, SIGNAL(replace(QString,int,QString)),
-                this, SLOT(corrected(QString,int,QString)));
+        connect(m_sonnetDialog, SIGNAL(replace(QString, int, QString)), this, SLOT(corrected(QString, int, QString)));
 
-        connect(m_sonnetDialog, SIGNAL(misspelling(QString,int)),
-                this, SLOT(misspelling(QString,int)));
+        connect(m_sonnetDialog, SIGNAL(misspelling(QString, int)), this, SLOT(misspelling(QString, int)));
 
-        connect(m_sonnetDialog, SIGNAL(cancel()),
-                this, SLOT(cancelClicked()));
+        connect(m_sonnetDialog, SIGNAL(cancel()), this, SLOT(cancelClicked()));
 
-        connect(m_sonnetDialog, SIGNAL(destroyed(QObject*)),
-                this, SLOT(objectDestroyed(QObject*)));
+        connect(m_sonnetDialog, SIGNAL(destroyed(QObject *)), this, SLOT(objectDestroyed(QObject *)));
 
-        connect(m_sonnetDialog, SIGNAL(languageChanged(QString)),
-                this, SLOT(languageChanged(QString)));
+        connect(m_sonnetDialog, SIGNAL(languageChanged(QString)), this, SLOT(languageChanged(QString)));
     }
 
+    m_view->bottomViewBar()->addBarWidget(m_sonnetDialog);
+
     m_userSpellCheckLanguage.clear();
     m_previousGivenSpellCheckLanguage.clear();
     delete m_globalSpellCheckRange;
     // we expand to handle the situation when the last word in the range is replace by a new one
-    m_globalSpellCheckRange = m_view->doc()->newMovingRange(KTextEditor::Range(start, end),
-                              KTextEditor::MovingRange::ExpandLeft | KTextEditor::MovingRange::ExpandRight);
+    m_globalSpellCheckRange = m_view->doc()->newMovingRange(KTextEditor::Range(start, end), KTextEditor::MovingRange::ExpandLeft | KTextEditor::MovingRange::ExpandRight);
     m_spellCheckCancelledByUser = false;
     performSpellCheck(*m_globalSpellCheckRange);
 }
@@ -176,8 +166,7 @@ void KateSpellCheckDialog::misspelling(const QString &word, int pos)
     int length;
     int origPos = m_view->doc()->computePositionWrtOffsets(m_currentDecToEncOffsetList, pos);
     cursor = locatePosition(origPos);
-    length = m_view->doc()->computePositionWrtOffsets(m_currentDecToEncOffsetList, pos + word.length())
-             - origPos;
+    length = m_view->doc()->computePositionWrtOffsets(m_currentDecToEncOffsetList, pos + word.length()) - origPos;
 
     m_view->setCursorPositionInternal(cursor, 1);
     m_view->setSelection(KTextEditor::Range(cursor, length));
@@ -187,15 +176,13 @@ void KateSpellCheckDialog::corrected(const QString &word, int pos, const QString
 {
     int origPos = m_view->doc()->computePositionWrtOffsets(m_currentDecToEncOffsetList, pos);
 
-    int length = m_view->doc()->computePositionWrtOffsets(m_currentDecToEncOffsetList, pos + word.length())
-                 - origPos;
+    int length = m_view->doc()->computePositionWrtOffsets(m_currentDecToEncOffsetList, pos + word.length()) - origPos;
 
     KTextEditor::Cursor replacementStartCursor = locatePosition(origPos);
     KTextEditor::Range replacementRange = KTextEditor::Range(replacementStartCursor, length);
     KTextEditor::DocumentPrivate *doc = m_view->doc();
     KTextEditor::EditorPrivate::self()->spellCheckManager()->replaceCharactersEncodedIfNecessary(newWord, doc, replacementRange);
 
-    m_currentSpellCheckRange.setRange(KTextEditor::Range(replacementStartCursor, m_currentSpellCheckRange.end()));
     // we have to be careful here: due to static word wrapping the text might change in addition to simply
     // the misspelled word being replaced, i.e. new line breaks might be inserted as well. As such, the text
     // in the 'Sonnet::Dialog' might be eventually out of sync with the visible text. Therefore, we 'restart'
@@ -207,6 +194,8 @@ void KateSpellCheckDialog::performSpellCheck(const KTextEditor::Range &range)
 {
     if (range.isEmpty()) {
         spellCheckDone();
+        m_sonnetDialog->closed();
+        return;
     }
     m_languagesInSpellCheckRange = KTextEditor::EditorPrivate::self()->spellCheckManager()->spellCheckLanguageRanges(m_view->doc(), range);
     m_currentLanguageRangeIterator = m_languagesInSpellCheckRange.begin();
@@ -217,31 +206,27 @@ void KateSpellCheckDialog::performSpellCheck(const KTextEditor::Range &range)
         m_view->bottomViewBar()->showBarWidget(m_sonnetDialog);
         m_sonnetDialog->show();
         m_sonnetDialog->setFocus();
+    } else {
+        m_sonnetDialog->closed();
     }
 }
 
 void KateSpellCheckDialog::installNextSpellCheckRange()
 {
-    if (m_spellCheckCancelledByUser
-            || m_currentLanguageRangeIterator == m_languagesInSpellCheckRange.end()) {
+    if (m_spellCheckCancelledByUser || m_currentLanguageRangeIterator == m_languagesInSpellCheckRange.end()) {
         spellCheckDone();
         return;
     }
     KateSpellCheckManager *spellCheckManager = KTextEditor::EditorPrivate::self()->spellCheckManager();
-    KTextEditor::Cursor nextRangeBegin = (m_currentSpellCheckRange.isValid() ? m_currentSpellCheckRange.end()
-                                          : KTextEditor::Cursor::invalid());
+    KTextEditor::Cursor nextRangeBegin = (m_currentSpellCheckRange.isValid() ? m_currentSpellCheckRange.end() : KTextEditor::Cursor::invalid());
     m_currentSpellCheckRange = KTextEditor::Range::invalid();
     m_currentDecToEncOffsetList.clear();
-    QList<QPair<KTextEditor::Range, QString> > rangeDictionaryPairList;
+    QList<QPair<KTextEditor::Range, QString>> rangeDictionaryPairList;
     while (m_currentLanguageRangeIterator != m_languagesInSpellCheckRange.end()) {
         const KTextEditor::Range &currentLanguageRange = (*m_currentLanguageRangeIterator).first;
         const QString &dictionary = (*m_currentLanguageRangeIterator).second;
-        KTextEditor::Range languageSubRange = (nextRangeBegin.isValid() ? KTextEditor::Range(nextRangeBegin, currentLanguageRange.end())
-                                               : currentLanguageRange);
-        rangeDictionaryPairList = spellCheckManager->spellCheckWrtHighlightingRanges(m_view->doc(),
-                                  languageSubRange,
-                                  dictionary,
-                                  false, true);
+        KTextEditor::Range languageSubRange = (nextRangeBegin.isValid() ? KTextEditor::Range(nextRangeBegin, currentLanguageRange.end()) : currentLanguageRange);
+        rangeDictionaryPairList = spellCheckManager->spellCheckWrtHighlightingRanges(m_view->doc(), languageSubRange, dictionary, false, true);
         Q_ASSERT(rangeDictionaryPairList.size() <= 1);
         if (rangeDictionaryPairList.size() == 0) {
             ++m_currentLanguageRangeIterator;
@@ -270,9 +255,7 @@ void KateSpellCheckDialog::installNextSpellCheckRange()
 
             m_currentDecToEncOffsetList.clear();
             KTextEditor::DocumentPrivate::OffsetList encToDecOffsetList;
-            QString text = m_view->doc()->decodeCharacters(m_currentSpellCheckRange,
-                           m_currentDecToEncOffsetList,
-                           encToDecOffsetList);
+            QString text = m_view->doc()->decodeCharacters(m_currentSpellCheckRange, m_currentDecToEncOffsetList, encToDecOffsetList);
             // ensure that no empty string is passed on to Sonnet as this can lead to a crash
             // (bug 228789)
             if (text.isEmpty()) {
@@ -311,7 +294,7 @@ void KateSpellCheckDialog::spellCheckDone()
 void KateSpellCheckDialog::objectDestroyed(QObject *object)
 {
     Q_UNUSED(object);
-    m_sonnetDialog = NULL;
+    m_sonnetDialog = nullptr;
 }
 
 void KateSpellCheckDialog::languageChanged(const QString &language)
@@ -319,5 +302,4 @@ void KateSpellCheckDialog::languageChanged(const QString &language)
     m_userSpellCheckLanguage = language;
 }
 
-//END
-
+// END
